@@ -353,6 +353,31 @@ class GameNode(object):
         if _board is None:
             return visitor.result()
 
+    def accept_subgame(self, visitor):
+        """
+        Traverses headers and game nodes in PGN order, as if the game was
+        starting from this node. Returns the visitor result.
+        """
+        game = self.root()
+        visitor.begin_game()
+
+        dummy_game = Game.without_tag_roster()
+        dummy_game.setup(self.board())
+
+        visitor.begin_headers()
+        for tagname, tagvalue in game.headers.items():
+            if tagname not in dummy_game.headers:
+                visitor.visit_header(tagname, tagvalue)
+        for tagname, tagvalue in dummy_game.headers.items():
+            visitor.visit_header(tagname, tagvalue)
+        visitor.end_headers()
+
+        self.accept(visitor)
+
+        visitor.visit_result(game.headers.get("Result", "*"))
+        visitor.end_game()
+        return visitor.result()
+
     def __str__(self):
         return self.accept(StringExporter(columns=None))
 
@@ -390,7 +415,12 @@ class Game(GameNode):
             "fischerandom",  # Cute Chess
             "fischerrandom"]
 
-        if chess960 or "Variant" not in self.headers:
+        # http://www.freechess.org/Help/HelpFiles/wild.html
+        wild = self.headers.get("Variant", "").lower() in [
+            "wild/0", "wild/1", "wild/2", "wild/3", "wild/4", "wild/5",
+            "wild/6", "wild/7", "wild/8", "wild/8a"]
+
+        if chess960 or wild or "Variant" not in self.headers:
             VariantBoard = chess.Board
         else:
             from chess.variant import find_variant
@@ -826,25 +856,27 @@ def read_game(handle, Visitor=GameModelCreator):
 
     dummy_game = Game.without_tag_roster()
     found_game = False
-    found_content = False
 
+    # Skip leading empty lines and comments.
     line = handle.readline()
+    while line.isspace() or line.startswith("%") or line.startswith(";"):
+        line = handle.readline()
 
     # Parse game headers.
     while line:
-        # Skip empty lines and comments.
-        if line.isspace() or line.startswith("%"):
+        # Skip comments.
+        if line.startswith("%") or line.startswith(";"):
             line = handle.readline()
             continue
 
-        if not found_game:
-            visitor.begin_game()
-            visitor.begin_headers()
-            found_game = True
-
         # Read header tags.
         tag_match = TAG_REGEX.match(line)
         if tag_match:
+            if not found_game:
+                found_game = True
+                visitor.begin_game()
+                visitor.begin_headers()
+
             dummy_game.headers[tag_match.group(1)] = tag_match.group(2)
             visitor.visit_header(tag_match.group(1), tag_match.group(2))
         else:
@@ -855,8 +887,8 @@ def read_game(handle, Visitor=GameModelCreator):
     if found_game:
         visitor.end_headers()
 
-    # Get the next non-empty line.
-    while line.isspace():
+    # Skip a single empty line after headers.
+    if line.isspace():
         line = handle.readline()
 
     # Movetext parser state.
@@ -870,18 +902,16 @@ def read_game(handle, Visitor=GameModelCreator):
     while line:
         read_next_line = True
 
-        if line.startswith("%"):
+        if line.startswith("%") or line.startswith(";"):
             # Ignore comments.
             line = handle.readline()
             continue
 
-        # An empty line means the end of a game.
-        if found_content and line.isspace():
-            if found_game:
-                visitor.end_game()
-                return visitor.result()
-            else:
-                return
+        # An empty line means the end of a game. But gracefully try to find
+        # at least some content if we didn't even see headers so far.
+        if found_game and line.isspace():
+            visitor.end_game()
+            return visitor.result()
 
         for match in MOVETEXT_REGEX.finditer(line):
             token = match.group(0)
@@ -943,20 +973,15 @@ def read_game(handle, Visitor=GameModelCreator):
                 visitor.end_variation()
                 board_stack.pop()
             elif token in ["1-0", "0-1", "1/2-1/2", "*"] and len(board_stack) == 1:
-                # Found a result token.
-                found_content = True
                 visitor.visit_result(token)
             else:
-                # Found a SAN token.
-                found_content = True
-
                 # Replace zeros castling notation.
                 if token == "0-0":
                     token = "O-O"
                 elif token == "0-0-0":
                     token = "O-O-O"
 
-                # Parse the SAN.
+                # Parse SAN tokens.
                 try:
                     move = board_stack[-1].parse_san(token)
                 except ValueError as error:
